==> bootstrap-7.1.25.tgz: package/tsDist/components/dashboard/widgets/YourKis/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import { InfoCircle } from 'components/icons';
import { TableWrapper } from '../../shared/SessionList/styles';
export var KisRow = styled('tbody')({
    fontSize: '0.85em',
    lineHeight: '1em',
    td: {
        lineHeight: '2.3em',
    },
});
export var TotalKisRow = styled(KisRow)(function (_a) {
    var theme = _a.theme;
    return ({
        td: {
            fontWeight: 600,
            borderTop: "1px solid " + theme.colors.secondaryText.default,
            button: {
                fontWeight: 'normal',
            },
        },
    });
});
export var KisCount = styled('td')(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 2.2em;\n  text-align: right;\n  padding: 0 0.3em 0 1em;\n"], ["\n  color: ", ";\n  font-size: 2.2em;\n  text-align: right;\n  padding: 0 0.3em 0 1em;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primary.default;
});
export var KisTitle = styled('td')(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  width: 100%;\n"], ["\n  width: 100%;\n"])));
export var KisTitleText = styled('span')(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  float: left;\n  margin-top: 2px;\n"], ["\n  float: left;\n  margin-top: 2px;\n"])));
export var InfoIcon = styled(InfoCircle)({
    width: '0.7em',
    height: '0.8em',
    transform: 'translateX(0.1em) translateY(-0.5em)',
}, function (_a) {
    var theme = _a.theme;
    return ({
        fill: theme.colors.secondaryText.default,
        '&:hover': {
            fill: theme.colors.primaryText.default,
            '& ~ span b': {
                color: theme.colors.primaryText.default,
            },
        },
    });
});
export var ErrorWrapper = styled(TableWrapper)({
    display: 'flex',
    height: 240,
    justifyContent: 'center',
    alignItems: 'center',
});
export var StyledContentLoader = styled(ContentLoader)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 52px;\n"], ["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 52px;\n"])));
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

==> bootstrap-7.2.31.tgz: package/tsDist/components/dashboard/widgets/YourKis/styles.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from 'styled-components';
import ContentLoader from 'react-content-loader';
import { InfoCircle } from 'components/icons';
import { TableWrapper } from '../../shared/SessionList/styles';
export var KisRow = styled('tbody')({
    fontSize: '0.85em',
    lineHeight: '1em',
    td: {
        lineHeight: '2.3em',
    },
});
export var TotalKisRow = styled(KisRow)(function (_a) {
    var theme = _a.theme;
    return ({
        td: {
            fontWeight: 600,
            borderTop: "1px solid " + theme.colors.secondaryText.default,
            button: {
                fontWeight: 'normal',
            },
        },
    });
});
export var KisCount = styled('td')(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  color: ", ";\n  font-size: 2.2em;\n  text-align: right;\n  padding: 0 0.3em 0 1em;\n"], ["\n  color: ", ";\n  font-size: 2.2em;\n  text-align: right;\n  padding: 0 0.3em 0 1em;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primary.default;
});
export var KisTitle = styled('td')(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  width: 100%;\n"], ["\n  width: 100%;\n"])));
export var KisTitleText = styled('span')(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  float: left;\n"], ["\n  float: left;\n"])));
export var InfoIcon = styled(InfoCircle)({
    width: 12,
    height: 12,
    transform: 'translateX(0.1em) translateY(-0.5em)',
}, function (_a) {
    var theme = _a.theme;
    return ({
        fill: theme.colors.secondaryText.default,
        '&:hover': {
            fill: theme.colors.primaryText.default,
            '& ~ span b': {
                color: theme.colors.primaryText.default,
            },
        },
    });
});
export var ErrorWrapper = styled(TableWrapper)({
    display: 'flex',
    height: 240,
    justifyContent: 'center',
    alignItems: 'center',
});
export var StyledContentLoader = styled(ContentLoader)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 52px;\n"], ["\n  flex-grow: 1;\n  flex-basis: 100%;\n  height: 52px;\n"])));
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;
